pub trait Wtf8Concat {
// Required method
fn fmt_wtf8(&self, buf: &mut Wtf8Buf);
}Expand description
Trait for types that can be appended to a Wtf8Buf, preserving surrogates.
pub trait Wtf8Concat {
// Required method
fn fmt_wtf8(&self, buf: &mut Wtf8Buf);
}Trait for types that can be appended to a Wtf8Buf, preserving surrogates.